@@ -238,9 +238,7 @@ def install_worker(modules_path, s3_base_workers_link, worker_name):
 def install_collector(collector_name, modules_path, s3_base_collectors_link):
     print ("adding collector " + collector_name)
     try:
-        print ("s3_base_collectors_link", s3_base_collectors_link)
         handle_prerequisites(s3_base_collectors_link, collector_name)
-        print("post handle_prerequisites")
         get_collector_files(collector_name, modules_path, s3_base_collectors_link)
 
     except Exception as e:
@@ -268,13 +266,9 @@ def get_collector_files(collector_name, modules_path, s3_base_collectors_link):
 
 def handle_prerequisites(s3_base_module_link, module_name):
     try:
-        print ("1")
         response = urllib.request.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
-        print ("2")
         requirements_file = response.read().decode('utf-8')
-        print ("3", "requirements_file", requirements_file)
         requirements_names = requirements_file.split("\n")
-        print("requirements_names", requirements_names)
         print ("This module requires the following packages to be installed:")
         for requirement in requirements_names:
             print (requirement)
@@ -297,5 +291,5 @@ def handle_prerequisites(s3_base_module_link, module_name):
                        "Please install the following before proceeding: " + str(missing_packages))
                 sys.exit(1)
     except Exception as e:
-        print ("Failed Exception : " + str(e))
+        print ("Failed to handle prerequisites for module", module_name, "Exception:", str(e))
         pass
